ERROR: This page was generated by inheriting from "layout.html".

Furo (the documentation theme that this site is generated with) does not support this, and has generated this page. If you are the author of this documentation, please look into why this page was generated using the "layout.html" template and fix the root cause.

Debugging information, if you need to report this error somewhere:

    Sphinx: {{ sphinx_version }}
    Furo: {{ furo_version }}

    pagename: {{ pagename }}